library airpackage;

import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:universal_html/html.dart' as html;


class AirAlert extends StatelessWidget {
  final String text;

  AirAlert({this.text});

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: Text(this.text),
      actions: <Widget>[
        FlatButton(
          child: Text('OK'),
          onPressed: () {
            Navigator.of(context).pop();
          },
        ),
      ],
    );
  }
}

class AirButton extends StatelessWidget {
  final Text label;
  final IconData icon;
  final Color color;
  final VoidCallback onPressed;

  AirButton({
    this.label,
    this.icon,
    this.color = AppColors.success,
    @required this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    return Cursor(
      child: RaisedButton.icon(
        label: label,
        color: color,
        elevation: 1,
        icon: Icon(icon),
        onPressed: onPressed,
        textColor: AppColors.white,
        highlightElevation: 0,
        disabledElevation: 0,
        highlightColor: Colors.transparent,
        textTheme: ButtonTextTheme.accent,
      ),
    );
  }
}

Container influencerAvatar({String url, Color color, double size = 26}) {
  return Container(
    width: size,
    height: size,
    decoration: BoxDecoration(
      border: Border.all(
        width: 2,
        color: color,
      ),
      borderRadius: BorderRadius.circular(size),
    ),
    child: CircleAvatar(
      radius: size,
      foregroundColor: color,
      backgroundImage: NetworkImage(url),
    ),
  );
}

class Cursor extends MouseRegion {
  static final appContainer =
      html.window.document.getElementById('app-container');

  Cursor({Widget child, CursorType cursor = Cursors.pointer})
      : super(
          onHover: (PointerHoverEvent evt) {
            appContainer.style.cursor = cursor.name;
          },
          onExit: (PointerExitEvent evt) {
            appContainer.style.cursor = 'default';
          },
          child: child,
        );
}

@immutable
class CursorType {
  final String name;
  const CursorType(this.name);
}

class Cursors {
  Cursors._();

  static const CursorType pointer = CursorType('pointer');
  static const CursorType auto = CursorType('auto');
  static const CursorType move = CursorType('move');
  static const CursorType noDrop = CursorType('no-drop');
  static const CursorType colResize = CursorType('col-resize');
  static const CursorType allScroll = CursorType('all-scroll');
  static const CursorType notAllowed = CursorType('not-allowed');
  static const CursorType rowResize = CursorType('row-resize');
  static const CursorType crosshair = CursorType('crosshair');
  static const CursorType progress = CursorType('progress');
  static const CursorType eResize = CursorType('e-resize');
  static const CursorType neResize = CursorType('ne-resize');
  static const CursorType text = CursorType('text');
  static const CursorType nResize = CursorType('n-resize');
  static const CursorType nwResize = CursorType('nw-resize');
  static const CursorType help = CursorType('help');
  static const CursorType verticalText = CursorType('vertical-text');
  static const CursorType sResize = CursorType('s-resize');
  static const CursorType seResize = CursorType('se-resize');
  static const CursorType inherit = CursorType('inherit');
  static const CursorType wait = CursorType('wait');
  static const CursorType wResize = CursorType('w-resize');
  static const CursorType swResize = CursorType('sw-resize');
}

class AppColors {
  AppColors._();

  static const Color black = Color(0xFF000000);
  static const Color white = Color(0xFFFFFFFF);
  static const Color transparent = Color(0x00000000);
  static const Color ig = Color(0XFF833AB4);
  static const Color fb = Color(0XFF3B5998);
  static const Color yt = Color(0XFFFF0000);
  static const Color tw = Color(0XFF1DA1F2);
  static const Color pt = Color(0XFFBD081C);
  static const Color status_active = Color(0XFFBD081C);
  static const Color status_inactive = Color(0XFFBD081C);
  static const Color status_archieve = Color(0XFFBD081C);

  static const int _primaryValue = 0xFFB924AD;
  static const MaterialColor primary = MaterialColor(
    _primaryValue,
    <int, Color>{
      50: Color(0xFFF8EBF7),
      100: Color(0xFFEBC3E8),
      200: Color(0xFFDF9BD9),
      300: Color(0xFFD273CA),
      400: Color(0xFFC54BBB),
      500: Color(_primaryValue),
      600: Color(0xFF981E8E),
      700: Color(0xFF76176F),
      800: Color(0xFF55114F),
      900: Color(0xFF330A30),
      1000: Color(0xFF110410),
    },
  );

  static const int _secondaryValue = 0xFF1E274B;
  static const MaterialColor secondary = MaterialColor(
    _secondaryValue,
    <int, Color>{
      50: Color(0xFF9BA7D7),
      100: Color(0xFF6477C1),
      200: Color(0xFF4458AA),
      300: Color(0xFF2F3E77),
      400: Color(0xFF273261),
      500: Color(_secondaryValue),
      600: Color(0xFF151C35),
      700: Color(0xFF0D101F),
      800: Color(0xFF040509),
      900: Color(0xFF030407),
    },
  );

  static const int _tertiaryValue = 0xFFC1C4CD;
  static const MaterialColor tertiary = MaterialColor(
    _tertiaryValue,
    <int, Color>{
      50: Color(0xFFEEEEF1),
      100: Color(0xFFE8E9EC),
      200: Color(0xFFE3E4E8),
      300: Color(0xFFE3E4E8),
      400: Color(0xFFD2D4DB),
      500: Color(_tertiaryValue),
      600: Color(0xFFB0B4BF),
      700: Color(0xFF9FA4B2),
      800: Color(0xFF8E94A4),
      900: Color(0xFF7D8396),
    },
  );

  static const int _grayValue = 0xFFF1F1F1;
  static const MaterialColor gray = MaterialColor(
    _grayValue,
    <int, Color>{
      50: Color(0xFFF1F1F1),
      100: Color(0xFFF1F1F1),
      200: Color(0xFFF1F1F1),
      300: Color(0xFFF1F1F1),
      400: Color(0xFFF1F1F1),
      500: Color(_grayValue),
      600: Color(0xFFF1F1F1),
      700: Color(0xFFF1F1F1),
      800: Color(0xFFF1F1F1),
      900: Color(0xFFF1F1F1),
    },
  );

  static const int _infoValue = 0xFF3998BE;
  static const MaterialColor info = MaterialColor(
    _infoValue,
    <int, Color>{
      50: Color(0xFFE7F3F7),
      100: Color(0xFFC4E0EC),
      200: Color(0xFF9CCCDF),
      300: Color(0xFF74B7D2),
      400: Color(0xFF57A7C8),
      500: Color(_infoValue),
      600: Color(0xFF3390B8),
      700: Color(0xFF2C85AF),
      800: Color(0xFF247BA7),
      900: Color(0xFF176A99),
    },
  );

  static const int _errorValue = 0xFFBE1335;
  static const MaterialColor error = MaterialColor(
    _errorValue,
    <int, Color>{
      50: Color(0xFFF7E3E7),
      100: Color(0xFFECB8C2),
      200: Color(0xFFDF899A),
      300: Color(0xFFD25A72),
      400: Color(0xFFC83653),
      500: Color(_errorValue),
      600: Color(0xFFB81130),
      700: Color(0xFFAF0E28),
      800: Color(0xFFA70B22),
      900: Color(0xFF990616),
    },
  );

  static const int _successValue = 0xFF09BE8E;
  static const MaterialColor success = MaterialColor(
    _successValue,
    <int, Color>{
      50: Color(0xFFE1F7F1),
      100: Color(0xFFB5ECDD),
      200: Color(0xFF84DFC7),
      300: Color(0xFF53D2B0),
      400: Color(0xFF2EC89F),
      500: Color(_successValue),
      600: Color(0xFF08B886),
      700: Color(0xFF06AF7B),
      800: Color(0xFF05A771),
      900: Color(0xFF02995F),
    },
  );

  static const int _warningValue = 0xFFBFB713;
  static const MaterialColor warning =
      MaterialColor(_warningValue, <int, Color>{
    50: Color(0xFFF7F6E3),
    100: Color(0xFFECE9B8),
    200: Color(0xFFDFDB89),
    300: Color(0xFFD2CD5A),
    400: Color(0xFFC9C236),
    500: Color(_warningValue),
    600: Color(0xFFB9B011),
    700: Color(0xFFB1A70E),
    800: Color(0xFFA99F0B),
    900: Color(0xFF9B9006),
  });
}

class AirIcons {
  AirIcons._();

  static const _fontFamily = 'AirIcons';

  static const IconData refresh = const IconData(0xe800, fontFamily: _fontFamily);
  static const IconData view_mosaic = const IconData(0xe801, fontFamily: _fontFamily);
  static const IconData view_list = const IconData(0xe802, fontFamily: _fontFamily);
  static const IconData view_first = const IconData(0xe803, fontFamily: _fontFamily);
  static const IconData view = const IconData(0xe804, fontFamily: _fontFamily);
  static const IconData video_post = const IconData(0xe805, fontFamily: _fontFamily);
  static const IconData users_outline = const IconData(0xe806, fontFamily: _fontFamily);
  static const IconData users = const IconData(0xe807, fontFamily: _fontFamily);
  static const IconData up = const IconData(0xe808, fontFamily: _fontFamily);
  static const IconData unshare = const IconData(0xe809, fontFamily: _fontFamily);
  static const IconData travel = const IconData(0xe80a, fontFamily: _fontFamily);
  static const IconData trash = const IconData(0xe80b, fontFamily: _fontFamily);
  static const IconData total_post = const IconData(0xe80c, fontFamily: _fontFamily);
  static const IconData topic_stories = const IconData(0xe80d, fontFamily: _fontFamily);
  static const IconData topic_beer = const IconData(0xe80e, fontFamily: _fontFamily);
  static const IconData topic_beauty = const IconData(0xe80f, fontFamily: _fontFamily);
  static const IconData tooltip = const IconData(0xe810, fontFamily: _fontFamily);
  static const IconData technology = const IconData(0xe811, fontFamily: _fontFamily);
  static const IconData symbol_airfluencers = const IconData(0xe812, fontFamily: _fontFamily);
  static const IconData stories = const IconData(0xe813, fontFamily: _fontFamily);
  static const IconData stamp_airscore = const IconData(0xe814, fontFamily: _fontFamily);
  static const IconData sports = const IconData(0xe815, fontFamily: _fontFamily);
  static const IconData social_youtube_circle = const IconData(0xe816, fontFamily: _fontFamily);
  static const IconData social_youtube = const IconData(0xe817, fontFamily: _fontFamily);
  static const IconData social_twitter_circle = const IconData(0xe818, fontFamily: _fontFamily);
  static const IconData social_twitter = const IconData(0xe819, fontFamily: _fontFamily);
  static const IconData social_pinterest = const IconData(0xe88d, fontFamily: _fontFamily);
  static const IconData social_pinterest_circle = const IconData(0xe81a, fontFamily: _fontFamily);
  static const IconData social_instagram_circle = const IconData(0xe81b, fontFamily: _fontFamily);
  static const IconData social_instagram = const IconData(0xe81c, fontFamily: _fontFamily);
  static const IconData social_facebook_circle = const IconData(0xe81d, fontFamily: _fontFamily);
  static const IconData social_facebook = const IconData(0xe81e, fontFamily: _fontFamily);
  static const IconData shared_economy = const IconData(0xe81f, fontFamily: _fontFamily);
  static const IconData share_network = const IconData(0xe820, fontFamily: _fontFamily);
  static const IconData share = const IconData(0xe821, fontFamily: _fontFamily);
  static const IconData settings = const IconData(0xe822, fontFamily: _fontFamily);
  static const IconData search = const IconData(0xe823, fontFamily: _fontFamily);
  static const IconData save = const IconData(0xe824, fontFamily: _fontFamily);
  static const IconData publipost = const IconData(0xe825, fontFamily: _fontFamily);
  static const IconData profile = const IconData(0xe826, fontFamily: _fontFamily);
  static const IconData priece = const IconData(0xe827, fontFamily: _fontFamily);
  static const IconData posts = const IconData(0xe828, fontFamily: _fontFamily);
  static const IconData post_campaign = const IconData(0xe829, fontFamily: _fontFamily);
  static const IconData politic = const IconData(0xe82a, fontFamily: _fontFamily);
  static const IconData plus = const IconData(0xe82b, fontFamily: _fontFamily);
  static const IconData planner_list = const IconData(0xe82c, fontFamily: _fontFamily);
  static const IconData pin_pinterest = const IconData(0xe82d, fontFamily: _fontFamily);
  static const IconData pin = const IconData(0xe82e, fontFamily: _fontFamily);
  static const IconData photo_post = const IconData(0xe82f, fontFamily: _fontFamily);
  static const IconData pet = const IconData(0xe830, fontFamily: _fontFamily);
  static const IconData others = const IconData(0xe831, fontFamily: _fontFamily);
  static const IconData nutrition = const IconData(0xe832, fontFamily: _fontFamily);
  static const IconData notification = const IconData(0xe833, fontFamily: _fontFamily);
  static const IconData no_results = const IconData(0xe834, fontFamily: _fontFamily);
  static const IconData my_list_circle = const IconData(0xe835, fontFamily: _fontFamily);
  static const IconData my_list = const IconData(0xe836, fontFamily: _fontFamily);
  static const IconData music = const IconData(0xe837, fontFamily: _fontFamily);
  static const IconData minus = const IconData(0xe838, fontFamily: _fontFamily);
  static const IconData martial_art = const IconData(0xe839, fontFamily: _fontFamily);
  static const IconData logout = const IconData(0xe83a, fontFamily: _fontFamily);
  static const IconData login = const IconData(0xe83b, fontFamily: _fontFamily);
  static const IconData literature = const IconData(0xe83c, fontFamily: _fontFamily);
  static const IconData link_external = const IconData(0xe83d, fontFamily: _fontFamily);
  static const IconData like_network = const IconData(0xe83e, fontFamily: _fontFamily);
  static const IconData like_heart = const IconData(0xe83f, fontFamily: _fontFamily);
  static const IconData lifestyle = const IconData(0xe840, fontFamily: _fontFamily);
  static const IconData life_family = const IconData(0xe841, fontFamily: _fontFamily);
  static const IconData language = const IconData(0xe842, fontFamily: _fontFamily);
  static const IconData kids = const IconData(0xe843, fontFamily: _fontFamily);
  static const IconData interation_text = const IconData(0xe844, fontFamily: _fontFamily);
  static const IconData info = const IconData(0xe845, fontFamily: _fontFamily);
  static const IconData import_icon = const IconData(0xe846, fontFamily: _fontFamily);
  static const IconData help = const IconData(0xe847, fontFamily: _fontFamily);
  static const IconData health = const IconData(0xe848, fontFamily: _fontFamily);
  static const IconData hair = const IconData(0xe849, fontFamily: _fontFamily);
  static const IconData growth = const IconData(0xe84a, fontFamily: _fontFamily);
  static const IconData graph_line = const IconData(0xe84b, fontFamily: _fontFamily);
  static const IconData graph_bar = const IconData(0xe84c, fontFamily: _fontFamily);
  static const IconData geolocation = const IconData(0xe84d, fontFamily: _fontFamily);
  static const IconData general_posts = const IconData(0xe84e, fontFamily: _fontFamily);
  static const IconData gastronomy = const IconData(0xe84f, fontFamily: _fontFamily);
  static const IconData form = const IconData(0xe850, fontFamily: _fontFamily);
  static const IconData fitness = const IconData(0xe851, fontFamily: _fontFamily);
  static const IconData filter = const IconData(0xe852, fontFamily: _fontFamily);
  static const IconData file = const IconData(0xe853, fontFamily: _fontFamily);
  static const IconData feed = const IconData(0xe854, fontFamily: _fontFamily);
  static const IconData favourite_circle = const IconData(0xe855, fontFamily: _fontFamily);
  static const IconData favourite = const IconData(0xe856, fontFamily: _fontFamily);
  static const IconData fashion = const IconData(0xe857, fontFamily: _fontFamily);
  static const IconData fall = const IconData(0xe858, fontFamily: _fontFamily);
  static const IconData export = const IconData(0xe859, fontFamily: _fontFamily);
  static const IconData expand = const IconData(0xe85a, fontFamily: _fontFamily);
  static const IconData etc_open = const IconData(0xe85b, fontFamily: _fontFamily);
  static const IconData etc = const IconData(0xe85c, fontFamily: _fontFamily);
  static const IconData error = const IconData(0xe85d, fontFamily: _fontFamily);
  static const IconData environment = const IconData(0xe85e, fontFamily: _fontFamily);
  static const IconData entertainment = const IconData(0xe85f, fontFamily: _fontFamily);
  static const IconData education = const IconData(0xe860, fontFamily: _fontFamily);
  static const IconData edit = const IconData(0xe861, fontFamily: _fontFamily);
  static const IconData duplicate = const IconData(0xe862, fontFamily: _fontFamily);
  static const IconData down = const IconData(0xe863, fontFamily: _fontFamily);
  static const IconData double_arrow_right = const IconData(0xe864, fontFamily: _fontFamily);
  static const IconData double_arrow_left = const IconData(0xe865, fontFamily: _fontFamily);
  static const IconData dislike = const IconData(0xe866, fontFamily: _fontFamily);
  static const IconData culture = const IconData(0xe867, fontFamily: _fontFamily);
  static const IconData construction = const IconData(0xe868, fontFamily: _fontFamily);
  static const IconData comment_post = const IconData(0xe869, fontFamily: _fontFamily);
  static const IconData comment = const IconData(0xe86a, fontFamily: _fontFamily);
  static const IconData close = const IconData(0xe86b, fontFamily: _fontFamily);
  static const IconData clock = const IconData(0xe86c, fontFamily: _fontFamily);
  static const IconData check = const IconData(0xe86d, fontFamily: _fontFamily);
  static const IconData certificate = const IconData(0xe86e, fontFamily: _fontFamily);
  static const IconData card_outline = const IconData(0xe86f, fontFamily: _fontFamily);
  static const IconData card_list_outline = const IconData(0xe870, fontFamily: _fontFamily);
  static const IconData card = const IconData(0xe871, fontFamily: _fontFamily);
  static const IconData calendar = const IconData(0xe872, fontFamily: _fontFamily);
  static const IconData calculator = const IconData(0xe873, fontFamily: _fontFamily);
  static const IconData business = const IconData(0xe874, fontFamily: _fontFamily);
  static const IconData brand = const IconData(0xe875, fontFamily: _fontFamily);
  static const IconData bio = const IconData(0xe876, fontFamily: _fontFamily);
  static const IconData beer = const IconData(0xe877, fontFamily: _fontFamily);
  static const IconData beauty = const IconData(0xe878, fontFamily: _fontFamily);
  static const IconData backoffice = const IconData(0xe879, fontFamily: _fontFamily);
  static const IconData back = const IconData(0xe87a, fontFamily: _fontFamily);
  static const IconData aviation = const IconData(0xe87b, fontFamily: _fontFamily);
  static const IconData avatar_profile = const IconData(0xe87c, fontFamily: _fontFamily);
  static const IconData automotive = const IconData(0xe87d, fontFamily: _fontFamily);
  static const IconData arrows = const IconData(0xe87e, fontFamily: _fontFamily);
  static const IconData archieve = const IconData(0xe87f, fontFamily: _fontFamily);
  static const IconData anchor = const IconData(0xe880, fontFamily: _fontFamily);
  static const IconData analytics_graphic = const IconData(0xe881, fontFamily: _fontFamily);
  static const IconData analytics = const IconData(0xe882, fontFamily: _fontFamily);
  static const IconData analyse = const IconData(0xe883, fontFamily: _fontFamily);
  static const IconData alert = const IconData(0xe884, fontFamily: _fontFamily);
  static const IconData airscore_leak = const IconData(0xe885, fontFamily: _fontFamily);
  static const IconData airscore = const IconData(0xe886, fontFamily: _fontFamily);
  static const IconData air_symbol = const IconData(0xe887, fontFamily: _fontFamily);
  static const IconData add_multiple = const IconData(0xe888, fontFamily: _fontFamily);
  static const IconData add_influencer = const IconData(0xe889, fontFamily: _fontFamily);
  static const IconData activism = const IconData(0xe88a, fontFamily: _fontFamily);
  static const IconData order_alphabet = const IconData(0xe88b, fontFamily: _fontFamily);
  static const IconData order_number = const IconData(0xe88c, fontFamily: _fontFamily);
}
